@@ -5,7 +5,7 @@ import kubernetes
 from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.logger import get_logger
 from ocp_resources.node import Node
-from ocp_resources.resource import NamespacedResource
+from ocp_resources.resource import NamespacedResource, kube_v1_api
 from ocp_resources.utils import TimeoutWatch
 
 
@@ -90,9 +90,8 @@ class Pod(NamespacedResource):
         error_channel = {}
         stream_closed_error = "stream resp is closed"
         LOGGER.info(f"Execute {command} on {self.name} ({self.node.name})")
-        kube_v1_api = kubernetes.client.CoreV1Api(api_client=self.client.client)
         resp = kubernetes.stream.stream(
-            api_method=kube_v1_api.connect_get_namespaced_pod_exec,
+            api_method=self._kube_v1_api.connect_get_namespaced_pod_exec,
             name=self.name,
             namespace=self.namespace,
             command=command,
@@ -147,7 +146,7 @@ class Pod(NamespacedResource):
         Returns:
             str: Pod logs.
         """
-        return self._kube_api.read_namespaced_pod_log(
+        return self._kube_v1_api.read_namespaced_pod_log(
             name=self.name, namespace=self.namespace, **kwargs
         )
 
@@ -167,3 +166,7 @@ class Pod(NamespacedResource):
     @property
     def ip(self):
         return self.instance.status.podIP
+
+    @property
+    def _kube_v1_api(self):
+        return kube_v1_api(api_client=self.client.client)
